.. _Utilities:

=========
Utilities
=========

This page describes the command line utilities that come with cgatreport
in detail.

.. _cgatreport-build:

.. automodule:: CGATReport.build

.. _cgatreport-quickstart:

.. automodule:: CGATReport.quickstart

.. _cgatreport-clean:

.. automodule:: CGATReport.clean

.. _cgatreport-test:

.. automodule:: CGATReport.test

.. _cgatreport-profile:

.. automodule:: CGATReport.profile

.. _cgatreport-get:

.. automodule:: CGATReport.get

.. _cgatreport-serve:

.. automodule:: CGATReport.serve

.. _cgatreport-gallery:

.. automodule:: CGATReport.gallery


